/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author:Matthieu Leclercq
 */

package org.objectweb.fractal.cecilia.adl.compiler.gnu;

import static org.objectweb.fractal.cecilia.adl.compiler.ExecutionHelper.exec;

import java.io.File;

import org.objectweb.fractal.adl.util.Printer;
import org.objectweb.fractal.cecilia.adl.compiler.AbstractCompilationTask;
import org.objectweb.fractal.cecilia.adl.compiler.CompilationException;
import org.objectweb.fractal.task.codegen.util.SourceFile;

public class GnuCompilerTask extends AbstractCompilationTask {

  protected final String gccCommand;

  // ---------------------------------------------------------------------------
  // Task constructor
  // ---------------------------------------------------------------------------

  /**
   * @param gccCommand the command of the Gnu C compiler to be executed by this
   *            task.
   * @param outputDir the directory into which the compiled file will be placed.
   * @param flags compilation flags.
   */
  public GnuCompilerTask(final String gccCommand, final File outputDir,
      final String flags) {
    super(outputDir, flags);
    this.gccCommand = gccCommand;
  }

  // ---------------------------------------------------------------------------
  // Implementation of abstract methods of AbstractCompilationTask
  // ---------------------------------------------------------------------------

  @Override
  protected void compile(final SourceFile sourceFile, final File outputFile)
      throws Exception {
    // forge command line.
    final String commandLine = gccCommand + " -c " + flags + " -o "
        + outputFile.getCanonicalPath() + " "
        + sourceFile.getFile().getCanonicalPath();

    // print debug or info message.
    if (Printer.isDebugEnable())
      Printer.debug("[gcc] " + commandLine);
    else if (Printer.isInfoEnable())
      Printer.info("[gcc] " + outputFile.getPath());

    // execute command
    final int rValue = exec(commandLine);
    if (rValue != 0) {
      throw new CompilationException("Error while compiling the file \""
          + sourceFile.getFile().getCanonicalPath() + "\"");
    }
  }
}
