/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.cecilia.adl.idl.exceptions;

import org.objectweb.fractal.adl.Node;
import org.objectweb.fractal.adl.interfaces.IDLException;

/**
 * Exception thrown when an IDL element (field or method) has an invalid name.
 */
public class DuplicatedNameException extends IDLException {

  private final Node previousNameDeclaration;

  /**
   * Constructs a new {@link DuplicatedNameException}.
   * 
   * @param signature the signature of the faulting IDL.
   * @param msg a detail message.
   * @param src where the error is located.
   * @param previousNameDeclaration the location of the previous name
   *          declaration.
   */
  public DuplicatedNameException(final String signature, final String msg,
      final Node src, final Node previousNameDeclaration) {
    super(signature, msg, src);
    this.previousNameDeclaration = previousNameDeclaration;
  }

  @Override
  public String getMessage() {
    return super.getMessage() + "(previous declaration at '"
        + previousNameDeclaration.astGetSource() + "')";
  }

  /**
   * @return the location of the previous name declaration.
   */
  public Node getPreviousNameDeclaration() {
    return previousNameDeclaration;
  }
}
