/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.cecilia.adl.types;

import org.objectweb.fractal.adl.Node;
import org.objectweb.fractal.adl.components.ComponentContainer;

/**
 * Utility class to manipulate Type decorations of {@link ComponentContainer}
 * node.
 */
public final class TypeDecorationUtil {
  private TypeDecorationUtil() {
  }

  /**
   * A decoration set of {@link ComponentContainer} nodes that give the AST that
   * defines the component type.
   */
  public static final String TYPE_DECORATION = "type";

  /**
   * Set the {@link #TYPE_DECORATION} decoration to the given component node
   * with the given type value.
   * 
   * @param component a component node.
   * @param type the type of the component node.
   * @throws IllegalArgumentException if the given component node already
   *             contains a {@link #TYPE_DECORATION} decoration.
   */
  public static void setTypeDecoration(final ComponentContainer component,
      final ComponentContainer type) {
    final Node compNode = component;
    if (compNode.astGetDecoration(TYPE_DECORATION) != null) {
      throw new IllegalArgumentException(
          "The given component node has already a \"" + TYPE_DECORATION
              + "\" decoration.");
    }
    compNode.astSetDecoration(TYPE_DECORATION, type);
  }

  /**
   * Returns the value of the {@link #TYPE_DECORATION} decoration for the given
   * component node.
   * 
   * @param component a component node.
   * @return the value of the {@link #TYPE_DECORATION} decoration for the given
   *         component node or <code>null</code> if the given node has no such
   *         decoration.
   */
  public static ComponentContainer getTypeDecoration(
      final ComponentContainer component) {
    return (ComponentContainer) ((Node) component)
        .astGetDecoration(TYPE_DECORATION);
  }
}
