/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.cecilia.adl.test;

import org.objectweb.fractal.adl.ADLException;

/**
 * Test ADL in test.attributes package.
 */
public class BindingsTest extends CeciliaAdlTestCase {

  public void testNoBinding() throws Exception {
    compileAndRun("test.bindings.NoBindingComposite");
  }

  public void testOptionalImportBinding() throws Exception {
    compileAndRun("test.bindings.OptionalImportBinding");
  }

  public void testCustomBindingControllerMC() throws Exception {
    compileAndRun("test.bindings.CustomBindingControllerMC");
  }

  public void testCustomImportedBindingControllerMC() throws Exception {
    compileAndRun("test.bindings.CustomImportedBindingControllerMC");
  }

  public void testCollectionBindingControllerMC() throws Exception {
    compileAndRun("test.bindings.CollectionBindingControllerMC");
  }

  public void testCollectionImportedBindingControllerMC() throws Exception {
    compileAndRun("test.bindings.CollectionImportedBindingControllerMC");
  }

  public void testBindAfterStart() throws Exception {
    compileAndRun("test.bindings.BindAfterStart");
  }

  public void testBindAfterStartImported() throws Exception {
    compileAndRun("test.bindings.BindAfterStartImported");
  }

  public void testBindAfterStartImported2() throws Exception {
    compileAndRun("test.bindings.BindAfterStartImported2");
  }

  public void testUsedAtStart() throws Exception {
    compileAndRun("test.bindings.UsedAtStart");
  }

  public void testUsedAtStartImported() throws Exception {
    compileAndRun("test.bindings.UsedAtStartImported");
  }

  // test for Bug 307360
  public void testMultipleServers() throws Exception {
    compileAndRun("test.bindings.static.DelegatingServersMC");
  }

  /**
   * Test for Bug #307806 about binding incompatible signatures. Here we test
   * that the given ADL should not be compiled correctly by the toolchain.
   */
  public void testIncompatibleSignatureForBinding() throws Exception {
    try {
      tryCompileADL("test.bindings.incompatible.IncompatibleBinding");
      fail("Should throw an ADLException because there are bindings with incompatible signatures");
    } catch (final ADLException e) {
      // OK
    }
  }
}
