/***
 * Fractal Task Codegen Framework
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.task.codegen.lib;

import org.objectweb.fractal.task.codegen.api.FactoryProviderTask;
import org.objectweb.fractal.task.codegen.api.InstanceProviderTask;
import org.objectweb.fractal.task.codegen.api.RequireFactoryProviderTask;
import org.objectweb.fractal.task.codegen.api.RequireInstanceProviderTask;
import org.objectweb.fractal.task.codegen.api.SourceCodeProviderTask;
import org.objectweb.fractal.task.core.AbstractTask;
import org.objectweb.fractal.task.core.TaskMap;

/**
 * Provides default implementation of the {@link SourceCodeProviderTask}.
 */
public abstract class AbstractSourceCodeProviderTask extends AbstractTask
    implements
      RequireFactoryProviderTask,
      RequireInstanceProviderTask,
      SourceCodeProviderTask {

  private TaskMap.TaskHole factoryProviderTask;
  private TaskMap.TaskHole instanceProviderTask;
  private Object           providedSourceCode;

  protected void setResult(final Object result) {
    this.providedSourceCode = result;
  }

  // --------------------------------------------------------------------------
  // Implementation of the RequireFactoryProviderTask interface
  // --------------------------------------------------------------------------

  public FactoryProviderTask getFactoryProviderTask() {
    return (factoryProviderTask == null)
        ? null
        : (FactoryProviderTask) factoryProviderTask.getTask();
  }

  public void setFactoryProviderTask(final TaskMap.TaskHole task) {
    if (factoryProviderTask != null) removePreviousTask(factoryProviderTask);
    factoryProviderTask = task;
    if (factoryProviderTask != null) addPreviousTask(factoryProviderTask);
  }

  // --------------------------------------------------------------------------
  // Implementation of the RequireInstanceProviderTask interface
  // --------------------------------------------------------------------------

  public InstanceProviderTask getInstanceProviderTask() {
    return (instanceProviderTask == null)
        ? null
        : (InstanceProviderTask) instanceProviderTask.getTask();
  }

  public void setInstanceProviderTask(final TaskMap.TaskHole task) {
    if (instanceProviderTask != null) removePreviousTask(instanceProviderTask);
    instanceProviderTask = task;
    if (instanceProviderTask != null) addPreviousTask(instanceProviderTask);
  }

  // --------------------------------------------------------------------------
  // Implementation of the SingleSourceCodeProviderTask interface
  // --------------------------------------------------------------------------

  public Object getSourceCode() {
    return providedSourceCode;
  }

  // --------------------------------------------------------------------------
  // Implementation of the Task interface
  // --------------------------------------------------------------------------

  public Object getResult() {
    return getSourceCode();
  }
}
